Coverage for src/paperap/models/responses/list.py: 0%

1"""

2

3

4

5----------------------------------------------------------------------------

6

7 METADATA:

8

9 File: list.py

10 Project: paperap

11 Created: 2025-03-11

12 Version: 0.0.5

13 Author: Jess Mann

14 Email: jess@jmann.me

15 Copyright (c) 2025 Jess Mann

16

17----------------------------------------------------------------------------

18

19 LAST MODIFIED:

20

21 2025-03-11 By Jess Mann

22

23"""

24

25 from __future__ import annotations

26

27 from paperap.models.abstract import StandardModel

28

29

30 class ListResponse(StandardModel):

31 """

32 Not currently used, but kept for documentation or future expansion.

33

34 The structure of an api response from paperless ngx for a list of models.

35 """

36

37 count: int

38 next: str | None

39 previous: str | None

40 all: list[int]

41 results: list[StandardModel]